==> splitty-1.0.25.tgz: package/app/files/controller.js <==
var fs = require("fs");
function getFileSeparator(){
        var isWin = /^win/.test(process.platform);
        if(isWin) return "\r\n";
        return "\n";
}
module.exports = (function(){
    var self = {};    
    /** Find files by name in the workspace */
    self.fileSave = function(data){
        var config = require('../conf/splitty');
        var path = config.workspace + data.filePath;
        if (data.filePath.startsWith(config.workspace)) {
            path = data.filePath;
        }
        fs.writeFile(path,data.lines.join(getFileSeparator()));
    };
    
    self.openFile = function(data){
        var config = require('../conf/splitty');
        var path = config.workspace + data.filename;
        var filePath = data.filename; 
        if (filePath.startsWith(config.workspace)) {
            path = filePath;
        }        
        fs.readFile(path, "utf-8", (err, data) => {
            if (err)  this.send("stderr",{"stderr":err});
            else {
                var fd = {};
                fd.data = data;
                fd.fileName = filePath;
                var spotSlash = filePath.split("/");
                var spotSplit = filePath.split(".");
                fd.extension = spotSplit[spotSplit.length - 1];
                fd.name = spotSlash[spotSlash.length - 1];
                this.send("openFile",fd);
            }
        });
    };
    
     self.find = function(data){
        var config = require('../conf/splitty');
        var parts = data.text.split("/");
        var out = [];
        var params = "./";
        var searchTerm = "*";
        var dirs = ["./"];
        var path = parts[0];
        if(parts.length > 1){
            params = parts;
            params = params.filter((e) => e != "");
            searchTerm = params[params.length - 1];
            params = params.slice(0,params.length-1);
            path ="./" + params.join("/");
        }
       dirs = ls(path);       
       if (dirs.length > 0) {
           dirs = find(path).filter((file) => file.match(data.text));
        }
        else {
           dirs = find("./").filter((file) => file.match(data.text));
        }
        this.send("find",{"founded":dirs.slice(0,50)});
    };
    
    return self;
})();

==> splitty-1.0.28.tgz: package/app/files/controller.js <==
var fs = require("fs");
function getFileSeparator(){
        var isWin = /^win/.test(process.platform);
        if(isWin) return "\r\n";
        return "\n";
}
module.exports = (function(){
    var self = {};    
    /** Find files by name in the workspace */
    self.fileSave = function(data){
        var config = require('../conf/splitty');
        var path = config.workspace + data.filePath;
        if (data.filePath.startsWith(config.workspace)) {
            path = data.filePath;
        }
        fs.writeFile(path,data.lines.join(getFileSeparator()));
    };
    
    self.openFile = function(data){
        var config = require('../conf/splitty');
        var path = config.workspace + data.filename;
        var filePath = data.filename; 
        if (filePath.startsWith(config.workspace)) {
            path = filePath;
        }        
        fs.readFile(path, "utf-8", (err, data) => {
            if (err)  this.send("stderr",{"stderr":err});
            else {
                var fd = {};
                fd.data = data;
                fd.fileName = filePath;
                var spotSlash = filePath.split("/");
                var spotSplit = filePath.split(".");
                fd.extension = spotSplit[spotSplit.length - 1];
                fd.name = spotSlash[spotSlash.length - 1];
                this.send("openFile",fd);
            }
        });
    };
    
     self.find = function(data){
        var config = require('../conf/splitty');
        var parts = data.text.split("/");
        var out = [];
        var params = "./";
        var searchTerm = "*";
        var dirs = ["./"];
        var path = parts[0];
        if(parts.length > 1){
            params = parts;
            params = params.filter((e) => e != "");
            searchTerm = params[params.length - 1];
            params = params.slice(0,params.length-1);
            path ="./" + params.join(delimiter());
        }
       dirs = ls(path);       
       if (dirs.length > 0) {
           dirs = find(path).filter((file) => file.match(data.text));
        }
        else {
           dirs = find("./").filter((file) => file.match(data.text));
        }
        this.send("find",{"founded":dirs.slice(0,50)});
    };
    
    return self;
})();
